@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::C;
-$Time::C::VERSION = '0.011';
+$Time::C::VERSION = '0.012';
 # ABSTRACT: Convenient time manipulation.
 
 use overload (
@@ -58,6 +58,13 @@ method from_string ($c: $str, $format = undef, $expected_tz = 'UTC') {
     bless {epoch => $p[0], tz => $p[1]}, $c;
 }
 
+
+method strptime ($c: $str, $format) {
+    my @p = _parse($str, $format, 'UTC');
+
+    bless {epoch => $p[0], tz => $p[1]}, $c;
+}
+
 fun _verify_tz ($tz) {
     _get_offset(time, $tz);
 }
@@ -106,14 +113,17 @@ fun _get_tz ($offset) {
 }
 
 fun _parse ($str, $format = undef, $tz = 'UTC') {
-    my $tp;
-    $tp = eval { Time::Piece->strptime($str, $format); } if defined $format;
-    my $tm = eval { defined $tp ?
-        Time::Moment->from_object($tp) :
-        Time::Moment->from_string($str);
-    };
+    my $tm;
 
-    croak sprintf "Could not parse %s.", $str if not defined $tm;
+    if (defined $format) {
+        my $tp = eval { local $ENV{TZ} = $tz; Time::Piece->localtime->strptime($str, $format); };
+        croak sprintf "Could not parse %s using %s.", $str, $format if not defined $tp;
+
+        $tm = Time::Moment->from_object($tp);
+    } else {
+        $tm = eval { Time::Moment->from_string($str); };
+        croak sprintf "Could not parse %s.", $str if not defined $tm;
+    }
 
     my $epoch = $tm->epoch;
     my $offset = $tm->offset;
@@ -141,10 +151,15 @@ method epoch ($t: $new_epoch = undef) :lvalue {
 }
 
 
-method tz ($t: $new_tz = undef) :lvalue {
+method tz ($t: $new_tz = undef, $override = 0) :lvalue {
     my $setter = sub {
         _verify_tz($_[0]);
 
+        if ($override) {
+            my $l = Time::C->new($t->year, $t->month, $t->day, $t->hour, $t->minute, $t->second, $_[0]);
+            $t->epoch = $l->epoch;
+        }
+
         $t->{tz} = $_[0];
         return $t if defined $new_tz;
         return $t->{tz};
@@ -237,6 +252,9 @@ method string ($t: $format = undef, $new_str = undef) :lvalue {
 }
 
 
+method strftime ($t: $format = undef, $new_str = undef) :lvalue { $t->string(@_); }
+
+
 method year ($t: $new_year = undef) :lvalue {
     my $tm = $t->tm();
 
@@ -416,6 +434,22 @@ method second ($t: $new_second = undef) :lvalue {
 }
 
 
+method second_of_day ($t: $new_second = undef) :lvalue {
+    my $tm = $t->tm();
+
+    my $setter = sub {
+        my $ret = ($t->tm = $tm->plus_seconds($_[0] - $tm->second_of_day))->second_of_day;
+
+        return $t if defined $new_second;
+        return $ret;
+    };
+
+    return $setter->($new_second) if defined $new_second;
+
+    sentinel value => $tm->second_of_day, set => $setter;
+}
+
+
 
 method diff ($t: $t2) {
     my $epoch =
@@ -448,7 +482,7 @@ Time::C - Convenient time manipulation.
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -601,6 +635,24 @@ If the parsed time contains a zone or offset that parses, and the offset matches
 
 =back
 
+=head2 strptime
+
+  my $t = Time::C->strptime($str, $format);
+
+Creates a Time::C object for the specified C<$str> using the C<$format> to parse it with L<Time::Piece/strptime>.
+
+=over
+
+=item C<$str>
+
+This is the string that will be parsed by L<Time::Piece/strptime>.
+
+=item C<$format>
+
+This is the format that L<Time::Piece/strptime> will be given.
+
+=back
+
 =head1 ACCESSORS
 
 These accessors will work as C<LVALUE>s, meaning you can assign to them to change the time being represented.
@@ -627,11 +679,14 @@ If the form C<< $t->epoch($new_epoch) >> is used, it likewise changes the epoch
   $t->tz = $tz;
 
   $t = $t->tz($new_tz);
+  $t = $t->tz($new_tz, $override);
 
 Returns or sets the timezone. If the timezone can't be recognised it dies.
 
 If the form C<< $t->tz($new_tz) >> is used, it likewise changes the timezone but returns the entire object.
 
+If C<$override> is a C<true> value, it changes the C<< $t->epoch >> as well, so that the date/time remains the same, but in a new timezone.
+
 =head2 offset
 
   my $offset = $t->offset;
@@ -664,10 +719,14 @@ If the form C<< $t->tm($new_tm) >> is used, it likewise changes the current epoc
 
   $t = $t->string($format, $new_str);
 
-Renders the current time to a string using the optional strftime C<$format>. If the C<$format> is not given it defaults to C<undef>. When setting this value, it tries to parse the string using L<Time::Piece/strptime> with the C<$format> or L<Time::Moment/from_string> if no C<$format> was given or strptime fails. If the detected C<offset> matches the current C<tz>, that is kept, otherwise it will get changed to a generic C<tz> in the form of C<Etc/GMT+X> or C<+XX:XX>.
+Renders the current time to a string using the optional strftime C<$format>. If the C<$format> is not given it defaults to C<undef>. When setting this value, it tries to parse the string using L<Time::Piece/strptime> with the C<$format> or L<Time::Moment/from_string> if no C<$format> was given. If the detected C<offset> matches the current C<tz>, that is kept, otherwise it will get changed to a generic C<tz> in the form of C<Etc/GMT+X> or C<+XX:XX>.
 
 If the form C<< $t->string($format, $new_str) >> is used, it likewise updates the epoch and timezone but returns the entire object.
 
+=head2 strftime
+
+Functions exactly like C<string>.
+
 =head2 year
 
   my $year = $t->year;
@@ -848,6 +907,22 @@ If the form C<< $t->second($new_second) >> is used, it likewise sets the current
 
 The second is 0-based where second 0 is the first second of the minute. Legal values are in the range 0-59.
 
+=head2 second_of_day
+
+  my $second = $t->second_of_day;
+  $t->second_of_day = $second;
+  $t->second_of_day += 86400;
+  $t->second_of_day++;
+  $t->second_of_day--;
+
+  $t = $t->second_of_day($new_second);
+
+Returns or sets the current second of the day, updating the epoch accordingly.
+
+If the form C<< $t->second_of_day($new_second) >> is used, it likewise sets the current second but returns the entire object.
+
+The second is 0-based where second 0 is the first second of the day. Legal values are in the range 0-86399.
+
 =head1 METHODS
 
 =head2 diff
@@ -869,14 +944,24 @@ Returns a copy of C<$t1>.
 
 =item L<Time::D>
 
+Like C<Time::C> but for durations.
+
 =item L<Time::R>
 
+If you need C<Time::C> times to recurr at regular intervals.
+
 =item L<Time::Moment>
 
+This implements most of the logic of this module.
+
 =item L<Time::Piece>
 
+For parsing times from strings using an strptime format.
+
 =item L<Time::Zone::Olson>
 
+Interfaces with the Olson timezone database.
+
 =back
 
 =head1 AUTHOR
