@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::R;
-$Time::R::VERSION = '0.011';
+$Time::R::VERSION = '0.012';
 # ABSTRACT: Handle recurrences.
 
 use overload (
@@ -198,15 +198,16 @@ method next ($r:) {
 
 
 method upcoming ($r:) {
+    my $c = $r->current->clone;
     $r->latest();
-    return $r->next();
+    my $n = $r->next();
+    $r->current = $c if not defined $n;
+    return $n;
 }
 
 
 method latest ($r:) {
-    # $r->reset();
-    # my @until = $r->reset->until(Time::C->now($r->start->tz));
-    my @until = $r->until(Time::C->now($r->start->tz));
+    my @until = $r->reset->until(Time::C->now($r->start->tz));
 
     return $until[-1];
 }
@@ -214,7 +215,7 @@ method latest ($r:) {
 
 method until ($r: $end) {
     croak "\$end is not a Time::C object" unless ref $end and $end->isa('Time::C');
-    $end = $r->end if $r->end->epoch < $end->epoch;
+    $end = $r->end if defined $r->end and $r->end->epoch < $end->epoch;
 
     my @results = $r->current();
     push @results, $_ while ($_ = $r->next() and $_->epoch <= $end->epoch);
@@ -243,7 +244,7 @@ Time::R - Handle recurrences.
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
